@@ -1,14 +1,20 @@
-# flake8: NOQA E5
+# flake8: NOQA: E501
+"""Sphinx documentation configuration for tmuxp."""
+
+import contextlib
 import inspect
+import pathlib
 import sys
 import typing as t
-from os.path import dirname, relpath
-from pathlib import Path
+from os.path import relpath
 
 import tmuxp
 
+if t.TYPE_CHECKING:
+    from sphinx.application import Sphinx
+
 # Get the project root dir, which is the parent dir of this
-cwd = Path(__file__).parent
+cwd = pathlib.Path(__file__).parent
 project_root = cwd.parent
 src_root = project_root / "src"
 
@@ -17,7 +23,7 @@ sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: t.Dict[str, str] = {}
-with open(src_root / "tmuxp" / "__about__.py") as fp:
+with (src_root / "tmuxp" / "__about__.py").open() as fp:
     exec(fp.read(), about)
 
 extensions = [
@@ -28,7 +34,7 @@ extensions = [
     "sphinx.ext.napoleon",
     "sphinx.ext.linkcode",
     "aafig",
-    "sphinx_click.ext",  # sphinx-click
+    "sphinxarg.ext",  # sphinx-argparse
     "sphinx_inline_tabs",
     "sphinx_copybutton",
     "sphinxext.opengraph",
@@ -51,7 +57,7 @@ source_suffix = {".rst": "restructuredtext", ".md": "markdown"}
 master_doc = "index"
 
 project = about["__title__"]
-copyright = about["__copyright__"]
+project_copyright = about["__copyright__"]
 
 version = "%s" % (".".join(about["__version__"].split("."))[:2])
 release = "%s" % (about["__version__"])
@@ -94,7 +100,7 @@ html_sidebars = {
         "sidebar/navigation.html",
         "sidebar/projects.html",
         "sidebar/scroll-end.html",
-    ]
+    ],
 }
 
 # linkify_issues
@@ -113,7 +119,6 @@ autodoc_default_options = {
 # sphinxext.opengraph
 ogp_site_url = about["__docs__"]
 ogp_image = "_static/img/icons/icon-192x192.png"
-ogp_desscription_length = about["__description__"]
 ogp_site_name = about["__title__"]
 
 # sphinx-copybutton
@@ -127,55 +132,19 @@ copybutton_remove_prompts = True
 rediraffe_redirects = "redirects.txt"
 rediraffe_branch = "master~1"
 
-htmlhelp_basename = "%sdoc" % about["__title__"]
-
-latex_documents = [
-    (
-        "index",
-        "{}.tex".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        "manual",
-    )
-]
-
-man_pages = [
-    (
-        "index",
-        about["__package_name__"],
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        1,
-    )
-]
-
-texinfo_documents = [
-    (
-        "index",
-        "{}".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        about["__package_name__"],
-        about["__description__"],
-        "Miscellaneous",
-    )
-]
+# aafig format, try to get working with pdf
+aafig_format = {"latex": "pdf", "html": "gif"}
+aafig_default_options = {"scale": 0.75, "aspect": 0.5, "proportional": True}
 
 intersphinx_mapping = {
     "python": ("https://docs.python.org/", None),
     "libtmux": ("https://libtmux.git-pull.com/", None),
-    "click": ("http://click.pocoo.org/5", None),
 }
 
-# aafig format, try to get working with pdf
-aafig_format = dict(latex="pdf", html="gif")
 
-aafig_default_options = dict(scale=0.75, aspect=0.5, proportional=True)
-
-
-def linkcode_resolve(domain, info):  # NOQA: C901
+def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     """
-    Determine the URL corresponding to Python object
+    Determine the URL corresponding to Python object.
 
     Notes
     -----
@@ -196,7 +165,7 @@ def linkcode_resolve(domain, info):  # NOQA: C901
     for part in fullname.split("."):
         try:
             obj = getattr(obj, part)
-        except Exception:
+        except Exception:  # NOQA: PERF203
             return None
 
     # strip decorators, which would resolve to the source of the decorator
@@ -206,7 +175,8 @@ def linkcode_resolve(domain, info):  # NOQA: C901
     except AttributeError:
         pass
     else:
-        obj = unwrap(obj)
+        if callable(obj):
+            obj = unwrap(obj)
 
     try:
         fn = inspect.getsourcefile(obj)
@@ -220,12 +190,9 @@ def linkcode_resolve(domain, info):  # NOQA: C901
     except Exception:
         lineno = None
 
-    if lineno:
-        linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1)
-    else:
-        linespec = ""
+    linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1) if lineno else ""
 
-    fn = relpath(fn, start=dirname(tmuxp.__file__))
+    fn = relpath(fn, start=pathlib.Path(tmuxp.__file__).parent)
 
     if "dev" in about["__version__"]:
         return "{}/blob/master/{}/{}/{}{}".format(
@@ -246,11 +213,14 @@ def linkcode_resolve(domain, info):  # NOQA: C901
         )
 
 
-def remove_tabs_js(app, exc):
+def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
+    """Fix for sphinx-inline-tabs#18."""
     if app.builder.format == "html" and not exc:
-        tabs_js = Path(app.builder.outdir) / "_static" / "tabs.js"
-        tabs_js.unlink()
+        tabs_js = pathlib.Path(app.builder.outdir) / "_static" / "tabs.js"
+        with contextlib.suppress(FileNotFoundError):
+            tabs_js.unlink()  # When python 3.7 deprecated, use missing_ok=True
 
 
-def setup(app):
+def setup(app: "Sphinx") -> None:
+    """Sphinx setup hook."""
     app.connect("build-finished", remove_tabs_js)
